;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
;+
; NAME: juldate
;
; PURPOSE:  gives julian date equivalent of a date in vairmer 
;           ( yymmdd or yyyymmdd ) format 
;           sets month, day and year to the corresp values
;
; CATEGORY: bidouilles dates
;
; CALLING SEQUENCE:  date = juldate(930124)
;
; INPUTS:date de la forme yymmdd ou yyyymmdd
;
; KEYWORD PARAMETERS:
;
;       VRAIDATE: pour ne pasa transformer l''annnee 01 en 1901 
;
; OUTPUTS:date en jour julien
;
; COMONTHON BLOCKS:
;	common.pro	vraidate
;
; SIDE EFFECTS:
;   l'annee 0 n'existant pas, qd year est nulle on calcule le
;     jour julien de l'annee -1.
;   COMPATIBLE AVEC L'AN 2000 !!!: une date de la forme yymmdd est
;    donvertit sous la forme yyyymmdd a l''aide de vraidate.
;   Attention, les variables globales year, month day sont attribuees
;
; MODIFICATION HISTORY: Jerome Vialard  (jv@lodyc.jussieu.fr)
;			2/7/98
;-
;------------------------------------------------------------
;------------------------------------------------------------
;------------------------------------------------------------
function juldate, vvdate, _EXTRA = ex
vdate = vvdate
vdate = vraidate(vdate, _EXTRA = ex)
@common
;------------------------------------------------------------
   year=vdate/10000
   month=vdate/100 - year*100
   day=abs(vdate - year*10000 - month*100)
   month = abs(month)
;
   mm = month & dd = day & yy = year
;------------------------------------------------------------
   ndate = n_elements(vdate) 
   if total(mm EQ 0) EQ ndate then mm[*] = 6
   if total(dd EQ 0) EQ ndate then dd[*] = 15
   if total(yy EQ 0) EQ ndate THEN yy[*] = -1
;------------------------------------------------------------
   return, julday(mm,dd,yy, _EXTRA = ex)
;------------------------------------------------------------
   return, -1
end
;------------------------------------------------------------

